summaryrefslogtreecommitdiffstats
path: root/tdeio/tdefile/tdefilepreview.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeio/tdefile/tdefilepreview.h')
-rw-r--r--tdeio/tdefile/tdefilepreview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tdeio/tdefile/tdefilepreview.h b/tdeio/tdefile/tdefilepreview.h
index 5bc59dba5..16cfa281b 100644
--- a/tdeio/tdefile/tdefilepreview.h
+++ b/tdeio/tdefile/tdefilepreview.h
@@ -89,10 +89,10 @@ public:
/**
* This overrides KFileView::actionCollection() by returning
* the actionCollection() of the KFileView (member left) it contains.
* This means that KFilePreview will never create a KActionCollection
* object of its own.
*/
- virtual KActionCollection * actionCollection() const;
+ virtual TDEActionCollection * actionCollection() const;
void ensureItemVisible(const KFileItem *);
@@ -89,10 +89,10 @@ public:
* This overrides KFileView::actionCollection() by returning
* the actionCollection() of the KFileView (member left) it contains.
- * This means that KFilePreview will never create a KActionCollection
+ * This means that KFilePreview will never create a TDEActionCollection
* object of its own.
*/